local keymap = vim.api.nvim_set_keymap
local default_ops = { noremap = true, silent = true }
local settings = vim.opt

-- PEP8 column
settings.colorcolumn = "80"

-- Handy stuff
keymap('n', '<Leader>m', 'iif __name__ == "__main__":<Esc>o    main()<Esc>o<Bs><Bs><Esc>', default_ops)
-- keymap('n', '<Leader>f', 'idef ():<Esc>bi', default_ops)

-- Indenting
keymap('v', '<', '<gv', default_ops)
keymap('v', '>', '>gv', default_ops)

-- [[ F1 - Execute current file ]]
-- Execute file
local Terminal = require('toggleterm.terminal').Terminal
local exec_python = Terminal:new({
	cmd = "echo %",
	direction = "float",
	count = 100,
	float_opts = { border = "curved" },
	close_on_exit = false
})
function _exec_python_toggle()
	exec_python:toggle()
end

-- keymap('n', '<F1>', ":w<CR>:exec '!clear;python3' shellescape(@%, 1)<CR>", default_ops)
keymap('n', '<F1>', ":lua _exec_python_toggle()<CR>", default_ops)

-- [[ F2 - iPython Terminal ]]
-- Toggle a custom Terminal with ipython
local ipython = Terminal:new({
	cmd = "ipython",
	direction = "horizontal",
	count = 200
})
function _ipython_toggle()
	ipython:toggle()
end

keymap('n', '<F2>', ":lua _ipython_toggle()<CR>", default_ops)
keymap('i', '<F2>', "<Esc>:lua _ipython_toggle()<CR><Cmd>wincmd k<CR>", default_ops)
keymap('t', '<F2>', "<Esc><Cmd>wincmd k<CR>:lua _ipython_toggle()<CR>", default_ops)

-- REPL to the ipython terminal
keymap('v', '<Leader>x', ':ToggleTermSendVisualLines 200<CR><CR><CR>', default_ops)
keymap('n', '<Leader>x', ':ToggleTermSendCurrentLine 200<CR><CR>', default_ops)

-- [[ F3 - Run Pytest ]]
-- Pytest
local pytest = Terminal:new({
	cmd = "python -m pytest",
	direction = "float",
	count = 300,
	float_opts = { border = "curved" },
	close_on_exit = false
})
function _pytest_toggle()
	pytest:toggle()
end

keymap('n', '<F3>', ":lua _pytest_toggle()<CR>", default_ops)
