return {

	-- Linter
	{
		'jose-elias-alvarez/null-ls.nvim',
		config = function()
			local nls = require("null-ls")
			nls.setup({
				sources = {
					nls.builtins.formatting.black,
				},
			})
		end,
	},

	-- Sessions
	{ "tpope/vim-obsession" },

	-- SuperTab
	{ 'ervandew/supertab' },

	-- Surround
	-- { 'tpope/vim-surround' },
	{ 'echasnovski/mini.surround', version = '*', config = true },

	-- Slime, for tmux repl-ing
	{ 'jpalardy/vim-slime' },

	-- Treesitter
	{
		'nvim-treesitter/nvim-treesitter',
		build = ':TSUpdate',
			highlight = {
				enable = true,
			},
			-- enable indentation
			indent = { enable = true },
			-- enable autotagging (w/ nvim-ts-autotag plugin)
			autotag = { enable = true },
			-- ensure these language parsers are installed
			ensure_installed = {
				"json",
				"yaml",
				"html",
				"css",
				"markdown",
				"bash",
				"lua",
				"vim",
				"dockerfile",
				"gitignore",
				"python",
			},
			-- auto install above language parsers
			auto_install = true,
	},

	-- Registry history
	{
		"AckslD/nvim-neoclip.lua",
		dependencies = {
			{ 'kkharji/sqlite.lua',           module = 'sqlite' },
			{ 'nvim-telescope/telescope.nvim' },
		},
		config = {
			enable_persistent_history = true,
			continuous_sync = true
		},
	},

	-- Auto pairs
	{ "windwp/nvim-autopairs",     config = true }, -- See `config` under https://github.com/folke/lazy.nvim#-plugin-spec

	-- Comment / uncomment
	{ "numToStr/Comment.nvim",     config = true },

	-- Git Repo Telescope
	{ 'cljoly/telescope-repo.nvim' },

	-- Which-Key
	{
		"folke/which-key.nvim",
		config = true,
	},

	-- File Explorer
	{
		"nvim-neo-tree/neo-tree.nvim",
		branch = "v2.x",
		dependencies = {
			"nvim-lua/plenary.nvim",
			"nvim-tree/nvim-web-devicons", -- not strictly required, but recommended
			"MunifTanjim/nui.nvim",
		},
		config = function()
			require("neo-tree").setup({
				close_if_last_window = true,
				popup_border_style = "rounded",
				window = {
					width = 40
				},
				mappings = {
					["P"] = "toggle_preview", -- enter preview mode, which shows the current node without focusing
				}
			})
		end
	},

	-- Terminal
	{
		'akinsho/toggleterm.nvim',
		version = "*",
		config = {
			open_mapping = [[<c-\>]],
			direction = 'horizontal'
		}
	},

	-- Markdown Preview
	{
		"iamcco/markdown-preview.nvim",
		build = "cd app && npm install",
		enabled = true,
		-- ft = "markdown",
	},

}
